from setuptools import find_packages, setup
setup(
    name='pyLuoyeeID',
    version='1.0.0',
    description='A python SDK for LuoyeeID',
    author='KainHao',
    author_email='kain@geekore.ink',
    url='https://paperfold.coding.net/public/luoyeidpass-pythonsdk/LuoyeeIDPass-Python-SDk/git/files',
    #install_requires=['requests'],
)